Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(886)

Unified Diff: pkg/http/test/utils.dart

Issue 16123036: Clean up dart:io exceptions. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/http/test/utils.dart
diff --git a/pkg/http/test/utils.dart b/pkg/http/test/utils.dart
index c2ce9c449723dc70b45c0991a9ea16c5775e41e6..5c7cc0262dfcf90ea8566416608c32ca98e7f5bc 100644
--- a/pkg/http/test/utils.dart
+++ b/pkg/http/test/utils.dart
@@ -196,14 +196,14 @@ class _RedirectLimitExceededException extends TypeMatcher {
item is RedirectLimitExceededException;
}
-/// A matcher for SocketIOExceptions.
-const isSocketIOException = const _SocketIOException();
+/// A matcher for SocketExceptions.
+const isSocketException = const _SocketException();
-/// A matcher for functions that throw SocketIOException.
-const Matcher throwsSocketIOException =
- const Throws(isSocketIOException);
+/// A matcher for functions that throw SocketException.
+const Matcher throwsSocketException =
+ const Throws(isSocketException);
-class _SocketIOException extends TypeMatcher {
- const _SocketIOException() : super("SocketIOException");
- bool matches(item, MatchState matchState) => item is SocketIOException;
+class _SocketException extends TypeMatcher {
+ const _SocketException() : super("SocketException");
+ bool matches(item, MatchState matchState) => item is SocketException;
}
« no previous file with comments | « pkg/http/test/safe_http_server.dart ('k') | pkg/scheduled_test/lib/src/scheduled_server/safe_http_server.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698